@@ -1,6 +1,4 @@
 package CatalystX::Features;
-our $VERSION = '0.11_01';
-
 use warnings;
 use strict;
 use Carp;
@@ -50,7 +48,7 @@ sub setup {
 sub features {
     my $c = shift;
 
-    $c->features_setup; # make sure it's loaded
+    $c->features_setup;
 
     return $c->config->{ $config_key }->{backend};
 }
