@@ -1,24 +1,22 @@
 package CatalystX::Features::Feature;
-our $VERSION = '0.11_01';
-
 use Moose;
 use Path::Class;
 use Catalyst::Utils;
 
-has 'backend' => ( is=>'ro', isa=>'CatalystX::Features::Role::Backend', weak_ref=>1, required=>1 );
+has 'backend' => ( is=>'ro', isa=>'CatalystX::Features::Role::Backend', required=>1 );
 
-has 'id'      => ( is => 'rw', isa => 'Str' );
-has 'name'    => ( is => 'rw', isa => 'Str' );
-has 'version' => ( is => 'rw', isa => 'Str', default => 'max' );
-has 'path'    => ( is => 'rw', isa => 'Str', trigger => \&_build_from_path );
+has 'id' => ( is=>'rw', isa=>'Str' );
+has 'name' => ( is=>'rw', isa=>'Str' );
+has 'version' => ( is=>'rw', isa=>'Str', default=>'1.0.0' );
+has 'path' => ( is=>'rw', isa=>'Str', trigger=> \&_build_args );
 
-has 'root' => ( is => 'rw', isa => 'Str' );
-has 'lib'  => ( is => 'rw', isa => 'Str' );
-has 't'    => ( is => 'rw', isa => 'Str' );
+has 'root' => ( is=>'rw', isa=>'Str' );
+has 'lib' => ( is=>'rw', isa=>'Str' );
+has 't' => ( is=>'rw', isa=>'Str' );
 
 with 'CatalystX::Features::Role::Feature';  # the interface role, place after 'has'
 
-sub _build_from_path {
+sub _build_args {
     my ($self, $value ) = @_;
 
     my $path = $self->path; 
@@ -42,7 +40,7 @@ sub version_number {
     if( $version =~ /\./ ) {
         my $number;
         foreach my $part ( split /\./, $version ) {
-            $number .= sprintf("%099d", $part );
+            $number .= sprintf("%03d", $part );
         }
         return $number;
     } else {
@@ -83,19 +81,19 @@ This is the object you get when you list features with $c->features.
 
 This is how this class implements the required interfaces from the role L<CatalystX::Features::Role::Feature>.
 
-=head2 id
+=head2 $c->id
 
 For a feature directory of "my.feature_1.0", the id part is "my.feature_1.0".
 
-=head2 name
+=head2 $c->name
 
 For a feature directory of "my.feature_1.0", the name is "my.feature".
 
-=head2 version
+=head2 $c->version
 
 For a feature directory of "my.feature_1.0", the version is "1.0".
 
-=head2 version_number
+=head2 $c->version_number
 
 A version long integer that can be compared easily. For a feature directory of "my.feature_1.2.3", the version number equals 001002003.
 
