@@ -1,6 +1,4 @@
 package CatalystX::Features::View::Mason;
-our $VERSION = '0.11_01';
-
 
 use strict;
 use warnings;
@@ -13,7 +11,7 @@ sub new {
 
     foreach my $feature ( $app->features->list ) {
 
-        my $prefix = $app->features->config->{ $feature->name }->{mason_prefix} || '';
+        my $prefix = $app->features->config->{ $feature->name }->{mason_prefix};
 
         if ( ref $prefix eq 'ARRAY' ) {
 			my $cnt;
