@@ -1,6 +1,4 @@
 package CatalystX::Features::View::TT;
-our $VERSION = '0.11_01';
-
 use strict;
 use warnings;
 use base 'Catalyst::View::TT';
@@ -16,7 +14,7 @@ sub new {
 
     foreach my $feature ( $app->features->list ) {
 
-        my $prefix = $app->features->config->{ $feature->name }->{tt_prefix} || '';
+        my $prefix = $app->features->config->{ $feature->name }->{tt_prefix};
 
         if ( ref $prefix eq 'ARRAY' ) {
             for ( @{$prefix} ) {
